@@ -407,7 +407,7 @@ class ChannelSet(object):
     def __iter__(self):
         # To make thread safe
         channel_vals = self._channels.values()
-        return channel_vals.__iter__
+        return channel_vals.__iter__()
 
     def checkCredentials(self, user, password):
         """Determines if credentials are valid.
@@ -449,14 +449,15 @@ class ChannelSet(object):
             if connection is None:
                 raise NotConnectedError('Client is not connected.')
 
-            cutoff_time = current_time - connection.channel.timeout
-            if connection.last_active < cutoff_time:
-                raise TimeOutError('Connection is timed out.')
-            
+            try:
+                cutoff_time = current_time - connection.channel.timeout
+                if connection.last_active < cutoff_time:
+                    raise TimeOutError('Connection is timed out.')
+            except TimeOutError:
+                connection.disconnect()
+                raise NotConnectedError('Client is not connected.')
+             
             connection.touch()
-        except TimeOutError:
-            connection.disconnect()
-            raise NotConnectedError('Client is not connected.')
         finally:
             self._lock.release()
 
